(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10346,        309]*)
(*NotebookOutlinePosition[     13172,        398]*)
(*  CellTagsIndexPosition[     12981,        387]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Solution to the System of Nonlinear Equations", "Section",
  PageBreakAbove->True,
  CellTags->{"i:56", "b:8.0", "c:40"}],

Cell[CellGroupData[{

Cell["Description", "SubsectionIcon",
  CellTags->{"b:8.0", "c:41"}],

Cell[TextData[{
  "Generate and verify the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " program that returns solution to the system of nonlinear equations:\n\
\[CapitalPhi]=",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a\ x\ y + x\^3 = 0\)},
              {\(a - x\ y\^2 = 0\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]]],
  "\nwhere x and y are unknowns and a is parameter."
}], "Text",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.0"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution", "SubsectionIcon",
  ShowCellBracket->True,
  CellTags->{"b:8.0", "c:42"}],

Cell[TextData[{
  "Here the appropriate ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " module is created."
}], "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.0"],

Cell[BoxData[""], "Input",
  CellLabel->"In[220]:=",
  CellTags->"b:8.0"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< AceGen`;\)\), "\[IndentingNewLine]", 
    \(\(SMSInitialize["\<test\>", "\<Environment\>" -> "\<MathLink\>"];\)\), \
"\n", 
    \(\(SMSModule["\<test\>", Real[x$$, y$$, a$$, tol$$], 
        Integer[n$$], \[IndentingNewLine]"\<Input\>" \[Rule] {x$$, y$$, a$$, 
            tol$$, n$$}, \[IndentingNewLine]"\<Output\>" \[Rule] {x$$, 
            y$$}];\)\), "\n", 
    \(\({x0, y0, a, \[Epsilon]} \[DoubleRightTee] 
        SMSReal[{x$$, y$$, a$$, tol$$}];\)\), "\n", 
    \(\(nmax = SMSInteger[n$$];\)\), "\[IndentingNewLine]", 
    \(\({x, y} \[DoubleLeftTee] {x0, y0};\)\), "\[IndentingNewLine]", 
    \(\(SMSDo[i, 1, nmax, 1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\t\(\[CapitalPhi] \[DoubleRightTee] {a\ \ x\ \ y + x\^3, 
          a\  - \ x\ y\^2};\)\), "\[IndentingNewLine]", 
    \(\t\(Kt \[DoubleRightTee] 
        SMSD[\[CapitalPhi], {x, y}];\)\), "\[IndentingNewLine]", 
    \(\t\({\[CapitalDelta]x, \[CapitalDelta]y} \[DoubleRightTee] 
        SMSLinearSolve[Kt, \(-\[CapitalPhi]\)];\)\), "\[IndentingNewLine]", 
    \(\t\({x, 
          y} \[LeftTee] {x, 
            y} + {\[CapitalDelta]x, \[CapitalDelta]y};\)\), "\
\[IndentingNewLine]", 
    \(\t\(SMSIf[
        SMSSqrt[{\[CapitalDelta]x, \[CapitalDelta]y} . {\[CapitalDelta]x, \
\[CapitalDelta]y}] < \[Epsilon]];\)\), "\n", 
    \(\t\t\(SMSExport[{x, y}, {x$$, y$$}];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSBreak[];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSEndIf[];\)\), "\n", 
    \(\t\(SMSIf[i \[Equal] nmax];\)\), "\n", 
    \(\t\t\(SMSPrint["\<'no convergion'\>"];\)\), "\[IndentingNewLine]", 
    \(\t\t\(SMSReturn[];\)\), "\[IndentingNewLine]", 
    \(\t\(SMSEndIf[];\)\), "\[IndentingNewLine]", 
    \(\(SMSEndDo[];\)\), "\n", 
    \(\(SMSWrite[];\)\)}], "Input",
  CellLabel->"In[221]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    InterpretationBox[\("Solution of "\[InvisibleSpace]2\[InvisibleSpace]" \
linear equations."\),
      SequenceForm[ "Solution of ", 2, " linear equations."],
      Editable->False]], "Print",
  CellLabel->"From In[221]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"Method : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"test\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "15", 
        "\[InvisibleSpace]", "\<\" formulae, \"\>", "\[InvisibleSpace]", 
        "147", "\[InvisibleSpace]", "\<\" sub-expressions\"\>"}],
      SequenceForm[ 
        StyleForm[ 
        "Method : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "test", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " ", 15, " formulae, ", 
        147, " sub-expressions"],
      Editable->False]], "Print",
  CellLabel->"From In[221]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"[\"\>", "\[InvisibleSpace]", "1", 
        "\[InvisibleSpace]", "\<\"] \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"File created : \"\>",
            Background->RGBColor[0.996109, 0.996109, 0]],
          (
          StyleForm[ #, Background -> 
            RGBColor[ .99610900000000002, .99610900000000002, 0]]&)], 
        "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"test.c\"\>",
            FontSize->20,
            FontWeight->"Bold",
            FontColor->RGBColor[0, 0.589853, 0]],
          (
          StyleForm[ #, FontWeight -> "Bold", FontColor -> RGBColor[ 
            0, .58985299999999996, 0], FontSize -> 20]&)], 
        "\[InvisibleSpace]", "\<\" Size : \"\>", "\[InvisibleSpace]", 
        "2472"}],
      SequenceForm[ "[", 1, "] ", 
        StyleForm[ 
        "File created : ", Background -> 
          RGBColor[ .99610900000000002, .99610900000000002, 0]], 
        StyleForm[ 
        "test.c", FontWeight -> "Bold", FontColor -> RGBColor[ 
          0, .58985299999999996, 0], FontSize -> 20], " Size : ", 2472],
      Editable->False]], "Print",
  CellLabel->"From In[221]:=",
  CellTags->"b:8.0"]
}, Closed]],

Cell[TextData[{
  "Here the ",
  StyleBox["MathLink",
    FontSlant->"Italic"],
  " program test.exe is build from the generated source code and installed so \
that functions defined in the source code can be called directly from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". (see also ",
  ButtonBox["SMSInstallMathLink",
    ButtonStyle->"AddOnsLink"],
  ")"
}], "MathCaption",
  CellTags->"b:8.0"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SMSInstallMathLink[]\)], "Input",
  CellLabel->"In[242]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(SMSMathLink["test", i_Integer, j_Integer : 0]\),
          HoldForm], ",", 
        TagBox[\(test[x_?NumberQ, y_?NumberQ, a_?NumberQ, tol_?NumberQ, 
            n_?NumberQ]\),
          HoldForm]}], "}"}]], "Output",
  CellLabel->"Out[242]=",
  CellTags->"b:8.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verification", "SubsectionIcon",
  CellTags->{"b:8.0", "c:43"}],

Cell["\<\
For the verification of the generated code the solution calculated by the \
build in function is compared with the solution calculated by the generated \
code.\
\>", "MathCaption",
  TextAlignment->Left,
  TextJustification->1,
  CellTags->"b:8.0"],

Cell[CellGroupData[{

Cell["test[1.9,-1.2,3.,0.0001,10]", "Input",
  CellLabel->"In[243]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    \({1.9331820449332464`, \(-1.2457309396162437`\)}\)], "Output",
  CellLabel->"Out[243]=",
  CellTags->"b:8.0"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x =. ; y =. ; a = 3. ;\), "\[IndentingNewLine]", 
    \(Solve[{a\ x\ y + x\^3 \[Equal] 0, a - \ x\ y\^2 \[Equal] 0}, {x, 
        y}]\)}], "Input",
  CellLabel->"In[244]:=",
  CellTags->"b:8.0"],

Cell[BoxData[
    \({{y \[Rule] \(-1.2457309396155176`\), 
        x \[Rule] 
          1.933182044931763`}, {y \[Rule] \(-0.38495203075986634`\) - 
            1.1847605276718223`\ \[ImaginaryI], 
        x \[Rule] \(-1.5639771275703094`\) - 
            1.1362958960074954`\ \[ImaginaryI]}, {y \[Rule] \
\(-0.38495203075986617`\) + 1.1847605276718227`\ \[ImaginaryI], 
        x \[Rule] \(-1.5639771275703094`\) + 
            1.1362958960074956`\ \[ImaginaryI]}, {y \[Rule] \
\(\(1.0078175005676253`\)\(\[InvisibleSpace]\)\) + 
            0.7322222746304465`\ \[ImaginaryI], 
        x \[Rule] \(\(0.5973861051044279`\)\(\[InvisibleSpace]\)\) - 
            1.8385653810171436`\ \[ImaginaryI]}, {y \[Rule] \
\(\(1.0078175005676253`\)\(\[InvisibleSpace]\)\) - 
            0.7322222746304466`\ \[ImaginaryI], 
        x \[Rule] \(\(0.597386105104428`\)\(\[InvisibleSpace]\)\) + 
            1.8385653810171436`\ \[ImaginaryI]}}\)], "Output",
  CellLabel->"Out[245]=",
  CellTags->"b:8.0"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 824}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{497, 712},
WindowMargins->{{107, Automatic}, {Automatic, 27}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:56"->{
    Cell[1776, 53, 127, 2, 91, "Section",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:8.0", "c:40"}]},
  "b:8.0"->{
    Cell[1776, 53, 127, 2, 91, "Section",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:8.0", "c:40"}],
    Cell[1928, 59, 68, 1, 39, "SubsectionIcon",
      CellTags->{"b:8.0", "c:41"}],
    Cell[1999, 62, 550, 16, 86, "Text",
      CellTags->"b:8.0"],
    Cell[2586, 83, 90, 2, 29, "SubsectionIcon",
      CellTags->{"b:8.0", "c:42"}],
    Cell[2679, 87, 202, 8, 25, "MathCaption",
      CellTags->"b:8.0"],
    Cell[2884, 97, 73, 2, 30, "Input",
      CellTags->"b:8.0"],
    Cell[2982, 103, 1822, 36, 491, "Input",
      CellTags->"b:8.0"],
    Cell[4807, 141, 260, 6, 23, "Print",
      CellTags->"b:8.0"],
    Cell[5070, 149, 1252, 31, 23, "Print",
      CellTags->"b:8.0"],
    Cell[6325, 182, 1225, 30, 23, "Print",
      CellTags->"b:8.0"],
    Cell[7565, 215, 414, 13, 59, "MathCaption",
      CellTags->"b:8.0"],
    Cell[8004, 232, 100, 3, 30, "Input",
      CellTags->"b:8.0"],
    Cell[8107, 237, 327, 9, 60, "Output",
      CellTags->"b:8.0"],
    Cell[8483, 252, 69, 1, 29, "SubsectionIcon",
      CellTags->{"b:8.0", "c:43"}],
    Cell[8555, 255, 258, 7, 42, "MathCaption",
      CellTags->"b:8.0"],
    Cell[8838, 266, 91, 2, 30, "Input",
      CellTags->"b:8.0"],
    Cell[8932, 270, 128, 3, 27, "Output",
      CellTags->"b:8.0"],
    Cell[9097, 278, 215, 5, 48, "Input",
      CellTags->"b:8.0"],
    Cell[9315, 285, 991, 19, 65, "Output",
      CellTags->"b:8.0"]},
  "c:40"->{
    Cell[1776, 53, 127, 2, 91, "Section",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:8.0", "c:40"}]},
  "c:41"->{
    Cell[1928, 59, 68, 1, 39, "SubsectionIcon",
      CellTags->{"b:8.0", "c:41"}]},
  "c:42"->{
    Cell[2586, 83, 90, 2, 29, "SubsectionIcon",
      CellTags->{"b:8.0", "c:42"}]},
  "c:43"->{
    Cell[8483, 252, 69, 1, 29, "SubsectionIcon",
      CellTags->{"b:8.0", "c:43"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:56", 11011, 326},
  {"b:8.0", 11139, 330},
  {"c:40", 12549, 370},
  {"c:41", 12676, 374},
  {"c:42", 12773, 377},
  {"c:43", 12870, 380}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 127, 2, 91, "Section",
  PageBreakAbove->True,
  CellTags->{"i:56", "b:8.0", "c:40"}],

Cell[CellGroupData[{
Cell[1928, 59, 68, 1, 39, "SubsectionIcon",
  CellTags->{"b:8.0", "c:41"}],
Cell[1999, 62, 550, 16, 86, "Text",
  CellTags->"b:8.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[2586, 83, 90, 2, 29, "SubsectionIcon",
  CellTags->{"b:8.0", "c:42"}],
Cell[2679, 87, 202, 8, 25, "MathCaption",
  CellTags->"b:8.0"],
Cell[2884, 97, 73, 2, 30, "Input",
  CellTags->"b:8.0"],

Cell[CellGroupData[{
Cell[2982, 103, 1822, 36, 491, "Input",
  CellTags->"b:8.0"],
Cell[4807, 141, 260, 6, 23, "Print",
  CellTags->"b:8.0"],
Cell[5070, 149, 1252, 31, 23, "Print",
  CellTags->"b:8.0"],
Cell[6325, 182, 1225, 30, 23, "Print",
  CellTags->"b:8.0"]
}, Closed]],
Cell[7565, 215, 414, 13, 59, "MathCaption",
  CellTags->"b:8.0"],

Cell[CellGroupData[{
Cell[8004, 232, 100, 3, 30, "Input",
  CellTags->"b:8.0"],
Cell[8107, 237, 327, 9, 60, "Output",
  CellTags->"b:8.0"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8483, 252, 69, 1, 29, "SubsectionIcon",
  CellTags->{"b:8.0", "c:43"}],
Cell[8555, 255, 258, 7, 42, "MathCaption",
  CellTags->"b:8.0"],

Cell[CellGroupData[{
Cell[8838, 266, 91, 2, 30, "Input",
  CellTags->"b:8.0"],
Cell[8932, 270, 128, 3, 27, "Output",
  CellTags->"b:8.0"]
}, Closed]],

Cell[CellGroupData[{
Cell[9097, 278, 215, 5, 48, "Input",
  CellTags->"b:8.0"],
Cell[9315, 285, 991, 19, 65, "Output",
  CellTags->"b:8.0"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

